#!/usr/bin/env python
# coding: utf-8

# # Dataset Creation from MD Trajectories

# The trajectories from GROMACS were post-processed to obtain properties using in-built commands.
# The following GROMACS tools were used corresponding to each of the features:
# 
# 1. bondener: gmx energy
# 2. lj-mol-wat: gmx energy
# 3. molwat-enthalpy: gmx energy
# 4. sasa: gmx sasa
# 5. lj-mol-lip: gmx energy
# 6. apl: gmx energy
# 7. rmsd-lip: gmx rms
# 8. rmsd-mollip: gmx rms

# We created separate folders for each property, stored the data files of all systems in the folders, and named the files appropriately.
# For example, a folder called **lj-mol-lip** contains the datafiles of drug-lipid Lennard-Jones interaction of all 630 systems.
# The files are named as 'C1-C1-DPPC-lj-mol-lip.xvg', 'P1-P2-DOPC-lj-mol-lip.xvg', and so on.



import numpy as np
import pandas as pd
import glob




# Importing the data for 'bondener' feature

bondener_files=glob.glob('bondener/*.xvg')
bondener_data=np.zeros((350,105))
i=0
for file in bondener_files:
    bondener_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
bondener_data = bondener_data




# Importing the data for 'lj-mol-wat' feature

ljmolwat_files=glob.glob('lj-mol-wat/*.xvg')
ljmolwat_data=np.zeros((350,105))
i=0
for file in ljmolwat_files:
    ljmolwat_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1

# Normalizing by number of beads
ljmolwat_data = ljmolwat_data/2     




# Importing the data for 'molwat-enthalpy' feature

molwatenthalpy_files=glob.glob('molwat-enthalpy/*.xvg')
molwatenthalpy_data=np.zeros((350,105))
i=0
for file in molwatenthalpy_files:
    molwatenthalpy_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
molwatenthalpy_data = molwatenthalpy_data




# Importing the data for 'sasa' feature

sasa_files=glob.glob('sasa/*.xvg')
sasa_data=np.zeros((350,105))
i=0
for file in sasa_files:
    sasa_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1

# Normalizing by number of beads
sasa_data = sasa_data/2




# As drug-water features are independent of the lipid type,
# we perform 105 simulations (corresponding to 105 coarse-grained dimers) and project the results for all six lipids

bondener_data= np.hstack((bondener_data,bondener_data,bondener_data,bondener_data,bondener_data,bondener_data)) 

ljmolwat_data= np.hstack((ljmolwat_data,ljmolwat_data,ljmolwat_data,ljmolwat_data,ljmolwat_data,ljmolwat_data))

molwatenthalpy_data= np.hstack((molwatenthalpy_data,molwatenthalpy_data,molwatenthalpy_data,molwatenthalpy_data,molwatenthalpy_data,molwatenthalpy_data))

sasa_data= np.hstack((sasa_data,sasa_data,sasa_data,sasa_data,sasa_data,sasa_data))




# Importing the data for 'lj-mol-lip' feature

ljmollipdppc_files=glob.glob('lj-mol-lip/*DPPC-lj-mol-lip.xvg')
ljmollipdopc_files=glob.glob('lj-mol-lip/*DOPC-lj-mol-lip.xvg')
ljmollippopc_files=glob.glob('lj-mol-lip/*POPC-lj-mol-lip.xvg')
ljmollipdlpc_files=glob.glob('lj-mol-lip/*DLPC-lj-mol-lip.xvg')
ljmollipdapc_files=glob.glob('lj-mol-lip/*DAPC-lj-mol-lip.xvg')
ljmollipdipc_files=glob.glob('lj-mol-lip/*DIPC-lj-mol-lip.xvg')
ljmollipdppc_data=np.zeros((350,105))
ljmollipdopc_data=np.zeros((350,105))
ljmollippopc_data=np.zeros((350,105))
ljmollipdlpc_data=np.zeros((350,105))
ljmollipdapc_data=np.zeros((350,105))
ljmollipdipc_data=np.zeros((350,105))
i=0
for file in ljmollipdppc_files:
    ljmollipdppc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in ljmollipdopc_files:
    ljmollipdopc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in ljmollippopc_files:
    ljmollippopc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in ljmollipdlpc_files:
    ljmollipdlpc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in ljmollipdapc_files:
    ljmollipdapc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in ljmollipdipc_files:
    ljmollipdipc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
ljmollip_data=np.hstack((ljmollipdppc_data,ljmollipdopc_data,ljmollippopc_data,ljmollipdlpc_data,ljmollipdapc_data,ljmollipdipc_data))

# Normalizing by number of beads
ljmollip_data = ljmollip_data/2




# Importing the data for 'apl' feature

boxlendppc_files=glob.glob('boxlen/*DPPC-boxlen.xvg')
boxlendopc_files=glob.glob('boxlen/*DOPC-boxlen.xvg')
boxlenpopc_files=glob.glob('boxlen/*POPC-boxlen.xvg')
boxlendlpc_files=glob.glob('boxlen/*DLPC-boxlen.xvg')
boxlendapc_files=glob.glob('boxlen/*DAPC-boxlen.xvg')
boxlendipc_files=glob.glob('boxlen/*DIPC-boxlen.xvg')
boxlendppc_data=np.zeros((350,105))
boxlendopc_data=np.zeros((350,105))
boxlenpopc_data=np.zeros((350,105))
boxlendlpc_data=np.zeros((350,105))
boxlendapc_data=np.zeros((350,105))
boxlendipc_data=np.zeros((350,105))
i=0
for file in boxlendppc_files:
    boxlendppc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in boxlendopc_files:
    boxlendopc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in boxlenpopc_files:
    boxlenpopc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in boxlendlpc_files:
    boxlendlpc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in boxlendapc_files:
    boxlendapc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
i=0
for file in boxlendipc_files:
    boxlendipc_data[:,i] = np.loadtxt(file, skiprows=25, usecols=1)
    i=i+1
boxlen_data = np.hstack((boxlendppc_data,boxlendopc_data,boxlenpopc_data,boxlendlpc_data,boxlendapc_data,boxlendipc_data))
print(boxlen_data.shape)

boxlensq = np.square(boxlen_data)
apl_data = boxlensq/64




# Importing the data for 'rmsd-lip' feature

rmsdlipdppc_files=glob.glob('rmsd-lip/*DPPC-rmsd-lip.xvg')
rmsdlipdopc_files=glob.glob('rmsd-lip/*DOPC-rmsd-lip.xvg')
rmsdlippopc_files=glob.glob('rmsd-lip/*POPC-rmsd-lip.xvg')
rmsdlipdlpc_files=glob.glob('rmsd-lip/*DLPC-rmsd-lip.xvg')
rmsdlipdapc_files=glob.glob('rmsd-lip/*DAPC-rmsd-lip.xvg')
rmsdlipdipc_files=glob.glob('rmsd-lip/*DIPC-rmsd-lip.xvg')
rmsdlipdppc_data = np.zeros((350,105))
rmsdlipdopc_data = np.zeros((350,105))
rmsdlippopc_data = np.zeros((350,105))
rmsdlipdlpc_data = np.zeros((350,105))
rmsdlipdapc_data = np.zeros((350,105))
rmsdlipdipc_data = np.zeros((350,105))
i=0
for file in rmsdlipdppc_files:
    rmsdlipdppc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdlipdopc_files:
    rmsdlipdopc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdlippopc_files:
    rmsdlippopc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdlipdlpc_files:
    rmsdlipdlpc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdlipdapc_files:
    rmsdlipdapc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdlipdipc_files:
    rmsdlipdipc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
rmsdlip_data = np.hstack((rmsdlipdppc_data,rmsdlipdopc_data,rmsdlippopc_data,rmsdlipdlpc_data,rmsdlipdapc_data,rmsdlipdipc_data))




# Importing the data for 'rmsd-mollip' feature

rmsdmollipdppc_files=glob.glob('rmsd-mollip/*DPPC-rmsd-mollip.xvg')
rmsdmollipdopc_files=glob.glob('rmsd-mollip/*DOPC-rmsd-mollip.xvg')
rmsdmollippopc_files=glob.glob('rmsd-mollip/*POPC-rmsd-mollip.xvg')
rmsdmollipdlpc_files=glob.glob('rmsd-mollip/*DLPC-rmsd-mollip.xvg')
rmsdmollipdapc_files=glob.glob('rmsd-mollip/*DAPC-rmsd-mollip.xvg')
rmsdmollipdipc_files=glob.glob('rmsd-mollip/*DIPC-rmsd-mollip.xvg')
rmsdmollipdppc_data = np.zeros((350,105))
rmsdmollipdopc_data = np.zeros((350,105))
rmsdmollippopc_data = np.zeros((350,105))
rmsdmollipdlpc_data = np.zeros((350,105))
rmsdmollipdapc_data = np.zeros((350,105))
rmsdmollipdipc_data = np.zeros((350,105))
i=0
for file in rmsdmollipdppc_files:
    rmsdmollipdppc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdmollipdopc_files:
    rmsdmollipdopc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdmollippopc_files:
    rmsdmollippopc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdmollipdlpc_files:
    rmsdmollipdlpc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdmollipdapc_files:
    rmsdmollipdapc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
i=0
for file in rmsdmollipdipc_files:
    rmsdmollipdipc_data[:,i] = np.loadtxt(file, skiprows=19, usecols=1)
    i=i+1
rmsdmollip_data = np.hstack((rmsdmollipdppc_data,rmsdmollipdopc_data,rmsdmollippopc_data,rmsdmollipdlpc_data,rmsdmollipdapc_data,rmsdmollipdipc_data))




# Combining all the features of all the systems in a single 3-D array to create the dataset

combined_data = np.dstack((bondener_data, ljmolwat_data, molwatenthalpy_data, sasa_data, ljmollip_data, apl_data, rmsdlip_data, rmsdmollip_data))
print(combined_data.shape)



# Getting the dataset in the appropriate shape for model building

dataset = np.transpose(combined_data, (1,0,2))
print(dataset.shape)



# Saving the dataset

np.save('dataset.npy', dataset)
